evaluate_spline

Function evaluate_spline 

pub fn evaluate_spline(
    locations: &[f32],
    derivatives: &[f32],
    input: f32,
    value_at: impl Fn(usize) -> f32,
) -> f32
Evaluate a spline defined by static data arrays.

locations, derivatives must have the same length. value_at(index) returns the value at a given point index (can be a constant or a nested spline evaluation).

Uses binary search + hermite cubic interpolation, matching vanilla’s CubicSpline.Multipoint.apply().